jaclearn.vision.coco.pycocotools.cocoeval
=========================================

.. automodule:: jaclearn.vision.coco.pycocotools.cocoeval

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      COCOeval
      Params
   
   

   
   
   

   
   
   








.. rubric:: Class COCOeval
.. autoclass:: COCOeval
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Params
.. autoclass:: Params
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







